@@ -1,6 +1,6 @@
+use strict; use warnings;
 package IO::All::STDIO;
-use strict;
-use warnings;
+
 use IO::All -base;
 use IO::File;
 
@@ -39,7 +39,7 @@ sub open {
     : fileno(STDIN);
     $self->io_handle(IO::File->new);
     $self->io_handle->fdopen($fileno, $mode);
-    $self->set_binmode;
+    $self->_set_binmode;
 }
 
 sub open_stderr {
@@ -51,33 +51,4 @@ sub open_stderr {
 
 # XXX Add overload support
 
-=encoding utf8
-
-=head1 NAME 
-
-IO::All::STDIO - STDIO Support for IO::All
-
-=head1 SYNOPSIS
-
-See L<IO::All>.
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2004. Brian Ingerson.
-
-Copyright (c) 2006, 2008. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
-
 1;
